@@ -1,12 +1,15 @@
-import os
+import gzip
 import json
-import boto3
-from pathlib import Path
+import os
 from datetime import timezone, datetime
+from io import BytesIO
+from pathlib import Path
 
+import boto3
 from interface import Interface
 
-# pylint: disable=no-init
+
+# pylint: disable=no-init, duplicate-code
 class BaseWriter(Interface):
     """
         Base Writer Class with methods to implement when creating your own custom writer.
@@ -160,12 +163,37 @@ class CustomS3JsonWriter(CustomLocalJsonWriter):
             Key=os.path.join(self.full_path, data_path).replace('\\', '/'),
             Body=json.dumps(json_data))
 
-    def write_file(self, data: dict):
+    def zip_write_to_s3(
+            self,
+            json_data,
+            data_path):
         """
-            upload python dict into s3 bucket with gzip archive
+            Write compressed report to s3 bucket
+        """
+
+        gz_body = BytesIO()
+        gz_file = gzip.GzipFile(None, 'wb', 7, gz_body)
+        gz_file.write(json.dumps(json_data).encode('utf-8'))
+        gz_file.close()
+
+        self.s3_resource.Bucket(self.bucket).put_object(
+            Key=os.path.join(self.full_path, data_path).replace('\\', '/'),
+            ContentEncoding='gzip',
+            Body=gz_body.getvalue()
+        )
+
+    def write_file(self, data: dict, compress=False):
+        """
+            Upload python dict into s3 bucket
+            args:
+                data (dict): report data to write
+                compress (bool): compress data written to s3
         """
 
         # generate a unix timestamp suffix for file
         self.data = data
-        self.write_to_s3(self.data, self.file_name)
+        if compress:
+            self.zip_write_to_s3(self.data, self.file_name)
+        else:
+            self.write_to_s3(self.data, self.file_name)
         self.data = []
