@@ -7,7 +7,7 @@ from urllib.error import URLError
 import pandas as pd
 import requests
 
-from sdc_dp_helpers.api_utilities.date_managers import phrase_to_date, date_handler
+from sdc_dp_helpers.api_utilities.date_managers import date_handler
 from sdc_dp_helpers.api_utilities.file_managers import load_file
 from sdc_dp_helpers.api_utilities.retry_managers import retry_handler
 
@@ -47,12 +47,38 @@ class CustomOneSignalReader:
         print("POST: csv_export.")
         # response is not always successful for some reason, so retry handler
         # handles the missing "csv_file_url" key response
-        response = self._request_session.post(
+        response: dict = self._request_session.post(
             url="https://onesignal.com/api/v1/players/csv_export",
             headers=self._header,
             json={"app_id": self._creds.get("app_id")},
-        ).json()["csv_file_url"]
+        ).json()
 
+        # status code is not always returned, so handling error strings instead
+        errors = response.get("errors", [None])[0]
+        if errors:
+            # The header is definitely valid, so we must assume the app_id is not
+            if (
+                errors
+                == "app_id not found. You may be missing a Content-Type: application/json header."
+            ):
+                raise EnvironmentError(
+                    "App Id may not be valid or removed from the account."
+                )
+
+            # Seems like we are restricted to making one query at a time for a given user, so wait 5 minutes
+            if (
+                errors
+                == "User already running another CSV export. Please wait until your other CSV exporter finishes and try again."
+            ):
+                time.sleep(300)  # the reader may try again after the 5 minute wait
+                raise EnvironmentError(errors)
+
+            # Raise all other unknown errors in a standard fashion
+            raise EnvironmentError(errors)
+        else:
+            print("No errors raised, fetching url.")
+
+        response = response["csv_file_url"]
         attempts = 0
         while True:
             try:
@@ -68,11 +94,19 @@ class CustomOneSignalReader:
                 if sd is not None and ed is not None:
                     # using a temp date field to select relevant data before dropping
                     data_frame["tmp_date"] = pd.to_datetime(data_frame["created_at"])
-                    data_frame["tmp_date"] = data_frame["tmp_date"].dt.strftime(_date_fmt)
+                    data_frame["tmp_date"] = data_frame["tmp_date"].dt.strftime(
+                        _date_fmt
+                    )
                     data_frame = data_frame[
-                        (data_frame["tmp_date"] >= datetime.strptime(sd, _date_fmt).strftime(_date_fmt)) &
-                        (data_frame["tmp_date"] <= datetime.strptime(ed, _date_fmt).strftime(_date_fmt))
-                        ]
+                        (
+                            data_frame["tmp_date"]
+                            >= datetime.strptime(sd, _date_fmt).strftime(_date_fmt)
+                        )
+                        & (
+                            data_frame["tmp_date"]
+                            <= datetime.strptime(ed, _date_fmt).strftime(_date_fmt)
+                        )
+                    ]
                     data_frame.drop("tmp_date", axis="columns", inplace=True)
                 break
             except URLError:
