@@ -10,18 +10,20 @@ def init_config(file_name: str = './example.yaml'):
         :file_name: Full path to config YAML file.
     """
     config = {
-        'query_config': [{
-            'action': 'stats',
-            'data': {
-                'stat': 'send',
-                'template': 'alert'}
+        "blast": {
+            "status": "sent",
+            "start_date": "yesterday",
+            "end_date": "yesterday"
         },
-            {'action': 'stats',
-             'data': {
-                 'stat': 'send',
-                 'template': 'alert subscribers'}
-             }
-        ]}
+        "list": {
+            "start_date": "yesterday",
+            "end_date": "yesterday"
+        },
+        "send": {
+            "start_date": "yesterday",
+            "end_date": "yesterday"
+        }
+    }
 
     # write to file
     with open(file_name, 'w') as file_:
